summaryrefslogtreecommitdiffstats
path: root/src/libs/engine/events
diff options
context:
space:
mode:
Diffstat (limited to 'src/libs/engine/events')
-rw-r--r--src/libs/engine/events/RequestPortValueEvent.cpp4
-rw-r--r--src/libs/engine/events/SetPortValueEvent.cpp8
-rw-r--r--src/libs/engine/events/SetPortValueQueuedEvent.cpp6
3 files changed, 9 insertions, 9 deletions
diff --git a/src/libs/engine/events/RequestPortValueEvent.cpp b/src/libs/engine/events/RequestPortValueEvent.cpp
index cd578460..e9766c9b 100644
--- a/src/libs/engine/events/RequestPortValueEvent.cpp
+++ b/src/libs/engine/events/RequestPortValueEvent.cpp
@@ -20,7 +20,7 @@
#include "Om.h"
#include "OmApp.h"
#include "interface/ClientInterface.h"
-#include "PortBase.h"
+#include "TypedPort.h"
#include "ObjectStore.h"
#include "ClientBroadcaster.h"
@@ -53,7 +53,7 @@ void
RequestPortValueEvent::execute(samplecount offset)
{
if (m_port != NULL && m_port->type() == DataType::FLOAT)
- m_value = ((PortBase<sample>*)m_port)->buffer(0)->value_at(offset);
+ m_value = ((TypedPort<sample>*)m_port)->buffer(0)->value_at(offset);
else
m_port = NULL; // triggers error response
diff --git a/src/libs/engine/events/SetPortValueQueuedEvent.cpp b/src/libs/engine/events/SetPortValueQueuedEvent.cpp
index c7750064..3e93b01b 100644
--- a/src/libs/engine/events/SetPortValueQueuedEvent.cpp
+++ b/src/libs/engine/events/SetPortValueQueuedEvent.cpp
@@ -18,7 +18,7 @@
#include "Responder.h"
#include "Om.h"
#include "OmApp.h"
-#include "PortBase.h"
+#include "TypedPort.h"
#include "ClientBroadcaster.h"
#include "Plugin.h"
#include "Node.h"
@@ -75,9 +75,9 @@ SetPortValueQueuedEvent::execute(samplecount offset)
if (m_error == NO_ERROR) {
assert(m_port != NULL);
if (m_voice_num == -1)
- ((PortBase<sample>*)m_port)->set_value(m_val, offset);
+ ((TypedPort<sample>*)m_port)->set_value(m_val, offset);
else
- ((PortBase<sample>*)m_port)->buffer(m_voice_num)->set(m_val, offset); // FIXME: check range
+ ((TypedPort<sample>*)m_port)->buffer(m_voice_num)->set(m_val, offset); // FIXME: check range
}
}
diff --git a/src/libs/engine/events/SetPortValueEvent.cpp b/src/libs/engine/events/SetPortValueEvent.cpp
index 046e935f..73672248 100644
--- a/src/libs/engine/events/SetPortValueEvent.cpp
+++ b/src/libs/engine/events/SetPortValueEvent.cpp
@@ -18,7 +18,7 @@
#include "Responder.h"
#include "Om.h"
#include "OmApp.h"
-#include "PortBase.h"
+#include "TypedPort.h"
#include "ClientBroadcaster.h"
#include "Node.h"
#include "ObjectStore.h"
@@ -62,10 +62,10 @@ SetPortValueEvent::execute(samplecount offset)
m_error = TYPE_MISMATCH;
} else {
if (m_voice_num == -1)
- ((PortBase<sample>*)m_port)->set_value(m_val, offset);
+ ((TypedPort<sample>*)m_port)->set_value(m_val, offset);
else
- ((PortBase<sample>*)m_port)->set_value(m_voice_num, m_val, offset);
- //((PortBase<sample>*)m_port)->buffer(m_voice_num)->set(m_val, offset); // FIXME: check range
+ ((TypedPort<sample>*)m_port)->set_value(m_voice_num, m_val, offset);
+ //((TypedPort<sample>*)m_port)->buffer(m_voice_num)->set(m_val, offset); // FIXME: check range
}
}